@@ -1,6 +1,6 @@
 /* xfce4-mpc-plugin.c
  *
- * Copyright (c) 2006-2018 Landry Breuil <landry at xfce.org>
+ * Copyright (c) 2006-2021 Landry Breuil <landry at xfce.org>
  * This code is licensed under a BSD-style license.
  * (OpenBSD variant modeled after the ISC license)
  * All rights reserved.
@@ -25,6 +25,7 @@
 #include <libxfce4ui/libxfce4ui.h>
 #include <string.h>
 #include <stdlib.h>
+#include <signal.h>
 #include <glib/gprintf.h>
 
 #include "xfce4-mpc-plugin.h"
@@ -32,6 +33,9 @@
 #define DEFAULT_MPD_HOST "localhost"
 #define DEFAULT_MPD_PORT 6600
 #define DIALOG_ENTRY_WIDTH 20
+#define TOOLTIP_TEXT _("... not connected?")
+#define TOOLTIP_FORMAT "Volume: %vol%% - Mpd %status%%newline%%artist% - %album% -/- (#%track%) %title%"
+#define PLAYLIST_FORMAT "%artist% - %album% -/- (#%track%) %title%"
 
 static void resize_button(GtkWidget *, gint, gint);
 
@@ -112,20 +116,28 @@ mpc_read_config (XfcePanelPlugin * plugin, t_mpc * mpc)
       g_free (mpc->playlist_format);
    if (mpc->client_appl != NULL)
       g_free (mpc->client_appl);
+   if (mpc->streaming_appl != NULL)
+      g_free (mpc->streaming_appl);
 
    mpc->mpd_host = g_strdup(xfce_rc_read_entry (rc, "mpd_host",  DEFAULT_MPD_HOST));
    mpc->mpd_port = xfce_rc_read_int_entry (rc, "mpd_port", DEFAULT_MPD_PORT);
    mpc->mpd_password = g_strdup(xfce_rc_read_entry (rc, "mpd_password", ""));
    mpc->show_frame = xfce_rc_read_bool_entry (rc, "show_frame", TRUE);
    mpc->client_appl = g_strdup(xfce_rc_read_entry (rc, "client_appl", "SETME"));
-   mpc->tooltip_format = g_strdup(xfce_rc_read_entry (rc, "tooltip_format", "Volume : %vol%% - Mpd %status%%newline%%%artist% - %album% -/- (#%track%) %title%"));
-   mpc->playlist_format = g_strdup(xfce_rc_read_entry (rc, "playlist_format", "%artist% - %album% -/- (#%track%) %title%"));
+   mpc->streaming_appl = g_strdup(xfce_rc_read_entry (rc, "streaming_appl", ""));
+   mpc->tooltip_format = g_strdup(xfce_rc_read_entry (rc, "tooltip_format", TOOLTIP_FORMAT));
+   mpc->playlist_format = g_strdup(xfce_rc_read_entry (rc, "playlist_format", PLAYLIST_FORMAT));
 
    label = gtk_bin_get_child(GTK_BIN(mpc->appl));
    g_snprintf(str, sizeof(str), "%s %s", _("Launch"), mpc->client_appl);
    gtk_label_set_text(GTK_LABEL(label),str);
 
-   DBG ("Settings read : %s@%s:%d\nframe:%d\nappl:%s\ntooltip:%s\nplaylist:%s", mpc->mpd_password, mpc->mpd_host, mpc->mpd_port, mpc->show_frame, mpc->client_appl, mpc->tooltip_format, mpc->playlist_format);
+   if (strlen(mpc->streaming_appl))
+      gtk_widget_show(GTK_WIDGET(mpc->stream));
+   else
+      gtk_widget_hide(GTK_WIDGET(mpc->stream));
+
+   DBG ("Settings read: %s@%s:%d\nframe:%d\nappl:%s\nstreaming:%s\ntooltip:%s\nplaylist:%s", mpc->mpd_password, mpc->mpd_host, mpc->mpd_port, mpc->show_frame, mpc->client_appl, mpc->streaming_appl, mpc->tooltip_format, mpc->playlist_format);
    xfce_rc_close (rc);
 }
 
@@ -157,6 +169,7 @@ static void mpc_write_config (XfcePanelPlugin * plugin, t_mpc * mpc)
    xfce_rc_write_entry (rc, "mpd_password", mpc->mpd_password);
    xfce_rc_write_bool_entry (rc, "show_frame", mpc->show_frame);
    xfce_rc_write_entry (rc, "client_appl", mpc->client_appl);
+   xfce_rc_write_entry (rc, "streaming_appl", mpc->streaming_appl);
    xfce_rc_write_entry (rc, "tooltip_format", mpc->tooltip_format);
    xfce_rc_write_entry (rc, "playlist_format", mpc->playlist_format);
 
@@ -187,21 +200,26 @@ mpc_dialog_apply_options (t_mpc_dialog *dialog)
    mpc->mpd_port = atoi(gtk_entry_get_text(GTK_ENTRY(dialog->textbox_port)));
    mpc->mpd_password = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog->textbox_password)));
    mpc->client_appl = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog->textbox_client_appl)));
+   mpc->streaming_appl = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog->textbox_streaming_appl)));
    mpc->tooltip_format = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog->textbox_tooltip_format)));
    mpc->playlist_format = g_strdup(gtk_entry_get_text(GTK_ENTRY(dialog->textbox_playlist_format)));
 
    if (0 == strlen(mpc->client_appl))
       mpc->client_appl = g_strdup("SETME");
    if (0 == strlen(mpc->tooltip_format))
-      mpc->tooltip_format = g_strdup("Volume : %vol%% - Mpd %status%%newline%%artist% - %album% -/- (#%track%) %title%");
+      mpc->tooltip_format = g_strdup(TOOLTIP_FORMAT);
    if (0 == strlen(mpc->playlist_format))
-      mpc->playlist_format = g_strdup("%artist% - %album% -/- (#%track%) %title%");
+      mpc->playlist_format = g_strdup(PLAYLIST_FORMAT);
+   if (strlen(mpc->streaming_appl))
+      gtk_widget_show(GTK_WIDGET(mpc->stream));
+   else
+      gtk_widget_hide(GTK_WIDGET(mpc->stream));
 
    label = gtk_bin_get_child(GTK_BIN(mpc->appl));
    g_snprintf(str, sizeof(str), "%s %s", _("Launch"), mpc->client_appl);
    gtk_label_set_text(GTK_LABEL(label),str);
 
-   DBG ("Apply: host=%s, port=%d, passwd=%s, appl=%s\ntooltip=%s\nplaylist=%s", mpc->mpd_host, mpc->mpd_port, mpc->mpd_password, mpc->client_appl, mpc->tooltip_format, mpc->playlist_format);
+   DBG ("Apply: host=%s, port=%d, passwd=%s, appl=%s, streaming=%s\ntooltip=%s\nplaylist=%s", mpc->mpd_host, mpc->mpd_port, mpc->mpd_password, mpc->client_appl, mpc->streaming_appl, mpc->tooltip_format, mpc->playlist_format);
 
    mpd_disconnect(mpc->mo);
    mpd_set_hostname(mpc->mo,mpc->mpd_host);
@@ -278,7 +296,7 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_grid_set_column_spacing (GTK_GRID(table), 12);
    gtk_grid_set_row_spacing (GTK_GRID(table), 6);
 
-   label = gtk_label_new(_("Host : "));
+   label = gtk_label_new(_("Host: "));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
    gtk_grid_attach(GTK_GRID(table), label, 0, 0, 1, 1);
 
@@ -288,7 +306,7 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_entry_set_text(GTK_ENTRY(dialog->textbox_host),mpc->mpd_host);
    gtk_grid_attach(GTK_GRID(table),dialog->textbox_host,1,0,1,1);
 
-   label = gtk_label_new(_("Port : "));
+   label = gtk_label_new(_("Port: "));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
    gtk_grid_attach(GTK_GRID(table), label, 0, 1, 1, 1);
 
@@ -298,7 +316,7 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_entry_set_text(GTK_ENTRY(dialog->textbox_port),str_port);
    gtk_grid_attach(GTK_GRID(table),dialog->textbox_port,1,1,1,1);
 
-   label = gtk_label_new(_("Password : "));
+   label = gtk_label_new(_("Password: "));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
    gtk_grid_attach(GTK_GRID(table), label, 0, 2, 1, 1);
 
@@ -308,7 +326,7 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_entry_set_text(GTK_ENTRY(dialog->textbox_password),mpc->mpd_password);
    gtk_grid_attach(GTK_GRID(table),dialog->textbox_password,1,2,1,1);
 
-   label = gtk_label_new(_("MPD Client : "));
+   label = gtk_label_new(_("MPD Client: "));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
    gtk_grid_attach(GTK_GRID(table), label, 0, 3, 1, 1);
 
@@ -317,27 +335,36 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_entry_set_text(GTK_ENTRY(dialog->textbox_client_appl),mpc->client_appl);
    gtk_grid_attach(GTK_GRID(table),dialog->textbox_client_appl,1,3,1,1);
 
-   label = gtk_label_new(_("Tooltip Format : "));
+   label = gtk_label_new(_("Streaming Client: "));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
    gtk_grid_attach(GTK_GRID(table), label, 0, 4, 1, 1);
 
+   dialog->textbox_streaming_appl = gtk_entry_new();
+   gtk_entry_set_width_chars(GTK_ENTRY(dialog->textbox_streaming_appl),DIALOG_ENTRY_WIDTH);
+   gtk_entry_set_text(GTK_ENTRY(dialog->textbox_streaming_appl),mpc->streaming_appl);
+   gtk_grid_attach(GTK_GRID(table),dialog->textbox_streaming_appl,1,4,1,1);
+
+   label = gtk_label_new(_("Tooltip Format: "));
+   gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+   gtk_grid_attach(GTK_GRID(table), label, 0, 5, 1, 1);
+
    dialog->textbox_tooltip_format = gtk_entry_new();
    gtk_entry_set_width_chars(GTK_ENTRY(dialog->textbox_tooltip_format),DIALOG_ENTRY_WIDTH);
    gtk_entry_set_text(GTK_ENTRY(dialog->textbox_tooltip_format),mpc->tooltip_format);
-   gtk_grid_attach(GTK_GRID(table),dialog->textbox_tooltip_format,1,4,1,1);
+   gtk_grid_attach(GTK_GRID(table),dialog->textbox_tooltip_format,1,5,1,1);
 
-   label = gtk_label_new(_("Playlist Format : "));
+   label = gtk_label_new(_("Playlist Format: "));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
-   gtk_grid_attach(GTK_GRID(table), label, 0, 5, 1, 1);
+   gtk_grid_attach(GTK_GRID(table), label, 0, 6, 1, 1);
 
    dialog->textbox_playlist_format = gtk_entry_new();
    gtk_entry_set_width_chars(GTK_ENTRY(dialog->textbox_playlist_format),DIALOG_ENTRY_WIDTH);
    gtk_entry_set_text(GTK_ENTRY(dialog->textbox_playlist_format),mpc->playlist_format);
-   gtk_grid_attach(GTK_GRID(table),dialog->textbox_playlist_format,1,5,1,1);
+   gtk_grid_attach(GTK_GRID(table),dialog->textbox_playlist_format,1,6,1,1);
 
    label = gtk_label_new_with_mnemonic(_("Show _frame"));
    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
-   gtk_grid_attach(GTK_GRID(table), label, 0, 6, 1, 1);
+   gtk_grid_attach(GTK_GRID(table), label, 0, 7, 1, 1);
 
    dialog->checkbox_frame = gtk_switch_new();
    gtk_switch_set_active(GTK_SWITCH(dialog->checkbox_frame),mpc->show_frame);
@@ -345,12 +372,13 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_widget_set_valign (GTK_WIDGET (dialog->checkbox_frame), GTK_ALIGN_CENTER);
 
    g_signal_connect (dialog->checkbox_frame, "state-set", G_CALLBACK (mpc_dialog_show_frame_toggled), dialog);
-   gtk_grid_attach(GTK_GRID(table),dialog->checkbox_frame,1,6,1,1);
+   gtk_grid_attach(GTK_GRID(table),dialog->checkbox_frame,1,7,1,1);
 
    gtk_widget_set_tooltip_text (dialog->textbox_host, _("Hostname or IP address"));
    gtk_widget_set_tooltip_text (dialog->textbox_client_appl, _("Graphical MPD Client to launch in plugin context menu"));
-   gtk_widget_set_tooltip_text (dialog->textbox_playlist_format, _("Variables : %artist%, %album%, %file%, %track% and %title%"));
-   gtk_widget_set_tooltip_text (dialog->textbox_tooltip_format, _("Variables : %vol%, %status%, %newline%, %artist%, %album%, %file%, %track% and %title%"));
+   gtk_widget_set_tooltip_text (dialog->textbox_streaming_appl, _("Command with url to stream MPD HTTP output"));
+   gtk_widget_set_tooltip_text (dialog->textbox_playlist_format, _("Variables: %artist%, %album%, %file%, %track% and %title%"));
+   gtk_widget_set_tooltip_text (dialog->textbox_tooltip_format, _("Variables: %vol%, %status%, %newline%, %artist%, %album%, %file%, %track% and %title%"));
 
    gtk_widget_show_all (table);
    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
@@ -359,11 +387,55 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
    gtk_widget_show (dlg);
 }
 
+static void
+child_watch_callback (GPid pid, gint status, gpointer user_data)
+{
+   DBG("streaming client with pid %d died with %d", pid, status);
+   ((t_mpc*) user_data)->is_streaming = FALSE;
+   ((t_mpc*) user_data)->streaming_child_pid = 0;
+   g_spawn_close_pid(pid);
+}
+
+static void
+mpc_launch_streaming(t_mpc* mpc)
+{
+   gchar **argv;
+   GError *error = NULL;
+   DBG("is streaming: %d (client \"%s\")", mpc->is_streaming, mpc->streaming_appl);
+   if (mpc->is_streaming || !strlen(mpc->streaming_appl))
+     return;
+   g_shell_parse_argv (mpc->streaming_appl, NULL, &argv, NULL);
+
+   DBG("Going to g_spawn_async(\"%s\")", mpc->streaming_appl);
+   mpc->is_streaming = g_spawn_async(NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD|G_SPAWN_SEARCH_PATH, NULL, NULL, &(mpc->streaming_child_pid), &error);
+   if (error && !mpc->is_streaming)
+   {
+     DBG("failed spawning: %s", error->message);
+     GtkWidget *dialog = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,_("Execution error"));
+     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
+     gtk_dialog_run (GTK_DIALOG (dialog));
+     gtk_widget_destroy (dialog);
+     g_error_free (error);
+   } else {
+     DBG("Spawned %d", mpc->streaming_child_pid);
+     g_child_watch_add(mpc->streaming_child_pid, child_watch_callback, mpc);
+   }
+}
+
+static void
+mpc_stop_streaming(t_mpc* mpc)
+{
+   DBG("stopping streaming client (pid %d)", mpc->streaming_child_pid);
+   if (mpc->streaming_child_pid) {
+      kill (mpc->streaming_child_pid, SIGTERM);
+   }
+}
+
 static void
 mpc_launch_client(GtkWidget *widget, t_mpc* mpc)
 {
    DBG("Going to xfce_exec(\"%s\")", mpc->client_appl);
-   xfce_spawn_command_line_on_screen(gdk_screen_get_default(), mpc->client_appl, FALSE, TRUE, NULL);
+   xfce_spawn_command_line(gdk_screen_get_default(), mpc->client_appl, FALSE, TRUE, FALSE, NULL);
 }
 
 static void
@@ -380,6 +452,15 @@ mpc_repeat_toggled(GtkWidget *widget, t_mpc* mpc)
    mpd_player_set_repeat(mpc->mo, gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)));
 }
 
+static void
+mpc_stream_toggled(GtkWidget *widget, t_mpc* mpc)
+{
+   DBG("!");
+   if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)))
+      mpc_launch_streaming(mpc);
+   else
+      mpc_stop_streaming(mpc);
+}
 static void
 mpc_output_toggled(GtkWidget *widget, t_mpc* mpc)
 {
@@ -454,11 +535,25 @@ format_song_display(mpd_Song* song, GString *str, t_mpc* mpc)
    if (0 == str->len)
       g_string_assign(str, mpc->playlist_format);
 
-   /* replace %artist% by song->artist, etc */
+   /* replace format strings with song data or placeholders */
+   if (song->artist == NULL)
+      song->artist = g_strdup(_("Unknown Artist"));
    str_replace(str, "%artist%", song->artist);
+
+   if (song->album == NULL)
+      song->album = g_strdup(_("Unknown Album"));
    str_replace(str, "%album%", song->album);
+
+   if (song->title == NULL)
+      song->title = g_strdup(_("Unknown Title"));
    str_replace(str, "%title%", song->title);
+
+   if (song->track == NULL)
+      song->track = g_strdup(_("Unknown Track"));
    str_replace(str, "%track%", song->track);
+
+   if (song->file == NULL)
+      song->file = g_strdup(_("Unknown File"));
    str_replace(str, "%file%", song->file);
 }
 
@@ -474,7 +569,7 @@ enter_cb(GtkWidget *widget, GdkEventCrossing* event, t_mpc* mpc)
    {
       if (!mpc_plugin_reconnect (mpc) || mpd_status_update (mpc->mo) != MPD_OK)
       {
-         gtk_widget_set_tooltip_text (mpc->box, _(".... not connected ?"));
+         gtk_widget_set_tooltip_text (mpc->box, TOOLTIP_TEXT);
          return FALSE;
       }
    }
@@ -489,26 +584,27 @@ enter_cb(GtkWidget *widget, GdkEventCrossing* event, t_mpc* mpc)
    switch (mpd_player_get_state(mpc->mo))
    {
       case MPD_PLAYER_PLAY:
-         str_replace(str, "%status%", "Playing");
+         str_replace(str, "%status%", _("Playing"));
          break;
       case MPD_PLAYER_PAUSE:
-         str_replace(str, "%status%", "Paused");
+         str_replace(str, "%status%", _("Paused"));
          break;
       case MPD_PLAYER_STOP:
-         str_replace(str, "%status%", "Stopped");
+         str_replace(str, "%status%", _("Stopped"));
          break;
       default:
-         str_replace(str, "%status%", "state ?");
+         str_replace(str, "%status%", "state?");
          break;
    }
    song = mpd_playlist_get_current_song(mpc->mo);
    if (song && song->id != -1)
       format_song_display(song, str, mpc);
    else
-      g_string_assign(str, "Failed to get song info ?");
+      g_string_assign(str, "Failed to get song info?");
 
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->random), mpd_player_get_random(mpc->mo));
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->repeat), mpd_player_get_repeat(mpc->mo));
+   gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->stream), mpc->is_streaming && mpc->streaming_child_pid);
    mpc_update_outputs(mpc);
 
    gtk_widget_set_tooltip_text (mpc->box, str->str);
@@ -546,7 +642,7 @@ show_playlist (t_mpc* mpc)
    MpdData *mpd_data;
    DBG("!");
 
-   str = g_string_new('\0');
+   str = g_string_new(NULL);
    if (mpc->playlist)
    {
       gtk_window_present(GTK_WINDOW(mpc->playlist));
@@ -621,12 +717,15 @@ toggle(GtkWidget *widget, GdkEventButton* event, t_mpc* mpc)
       switch (mpd_player_get_state(mpc->mo))
       {
          case MPD_PLAYER_PAUSE:
+            mpc_launch_streaming(mpc);
+            G_GNUC_FALLTHROUGH;
          case MPD_PLAYER_PLAY:
             mpd_player_pause(mpc->mo); /* toggles play/pause */
             break;
          case MPD_PLAYER_STOP:
          default:
             mpd_player_play(mpc->mo); /* if stopped, mpd_player_pause() doesn't restart playing */
+            mpc_launch_streaming(mpc);
             break;
       }
    }
@@ -705,7 +804,7 @@ scroll_cb(GtkWidget *widget, GdkEventScroll* event, t_mpc* mpc)
    {
       if (!mpc_plugin_reconnect (mpc) || mpd_status_update (mpc->mo) != MPD_OK)
       {
-         gtk_widget_set_tooltip_text(widget, _(".... not connected ?"));
+         gtk_widget_set_tooltip_text(widget, TOOLTIP_TEXT);
          return;
       }
    }
@@ -721,7 +820,7 @@ static void
 resize_button(GtkWidget *btn, gint size, gint icon_size)
 {
    GtkWidget *image = g_object_get_data(G_OBJECT(btn), "image");
-   gchar *icon = g_object_get_data(G_OBJECT(image), "icon-name");
+   G_GNUC_UNUSED gchar *icon = g_object_get_data(G_OBJECT(image), "icon-name");
    DBG("Resizing button to size %d and icon %s to size %d", size, icon, icon_size);
    gtk_image_set_pixel_size(GTK_IMAGE(image), icon_size);
    gtk_widget_set_size_request (btn, size, size);
@@ -789,16 +888,20 @@ mpc_create (XfcePanelPlugin * plugin)
    g_signal_connect (G_OBJECT(mpc->random), "toggled", G_CALLBACK (mpc_random_toggled), mpc);
    mpc->repeat = gtk_check_menu_item_new_with_label (_("Repeat"));
    g_signal_connect (G_OBJECT(mpc->repeat), "toggled", G_CALLBACK (mpc_repeat_toggled), mpc);
+   mpc->stream = gtk_check_menu_item_new_with_label (_("Stream"));
+   g_signal_connect (G_OBJECT(mpc->stream), "toggled", G_CALLBACK (mpc_stream_toggled), mpc);
    mpc->appl = gtk_menu_item_new_with_label (_("Launch"));
    g_signal_connect (G_OBJECT(mpc->appl), "activate", G_CALLBACK (mpc_launch_client), mpc);
 
    add_separator_and_label_with_markup(plugin, _("<b><i>Commands</i></b>"));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->random));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->repeat));
+   xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->stream));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->appl));
    add_separator_and_label_with_markup(plugin, _("<b><i>Outputs</i></b>"));
    gtk_widget_show (mpc->repeat);
    gtk_widget_show (mpc->random);
+   gtk_widget_show (mpc->stream);
    gtk_widget_show (mpc->appl);
    gtk_widget_show_all (mpc->box);
 
@@ -808,21 +911,16 @@ mpc_create (XfcePanelPlugin * plugin)
 static void
 mpc_show_about(XfcePanelPlugin *plugin, t_mpc* mpc)
 {
-   GdkPixbuf *icon;
    const gchar *auth[] = { "Landry Breuil <landry at xfce.org>", NULL };
-   icon = xfce_panel_pixbuf_from_source("applications-multimedia", NULL, 32);
    gtk_show_about_dialog(NULL,
-      "logo", icon,
+      "logo-icon-name", "applications-multimedia",
       "license", xfce_get_license_text (XFCE_LICENSE_TEXT_BSD),
       "version", PACKAGE_VERSION,
       "program-name", PACKAGE_NAME,
       "comments", _("A simple panel-plugin client for Music Player Daemon"),
-      "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-mpc-plugin",
-      "copyright", _("Copyright (c) 2006-2018 Landry Breuil\n"),
+      "website", "https://docs.xfce.org/panel-plugins/xfce4-mpc-plugin",
+      "copyright", "Copyright \302\251 2006-2023 The Xfce development team",
       "authors", auth, NULL);
-
-   if(icon)
-      g_object_unref(G_OBJECT(icon));
 }
 
 static void
@@ -831,7 +929,7 @@ mpc_construct (XfcePanelPlugin * plugin)
    t_mpc *mpc;
 
    DBG("!");
-#if DEBUG
+#ifdef DEBUG
 #if HAVE_LIBMPD
    debug_set_level(10);
 #endif
@@ -846,8 +944,10 @@ mpc_construct (XfcePanelPlugin * plugin)
    mpc->mpd_port = DEFAULT_MPD_PORT;
    mpc->mpd_password = g_strdup("");
    mpc->client_appl = g_strdup("SETME");
-   mpc->tooltip_format = g_strdup("Volume : %vol%% - Mpd %status%%newline%%artist% - %album% -/- (#%track%) %title%");
-   mpc->playlist_format = g_strdup("%artist% - %album% -/- (#%track%) %title%");
+   mpc->streaming_appl = g_strdup("");
+   mpc->streaming_child_pid = 0;
+   mpc->tooltip_format = g_strdup(TOOLTIP_FORMAT);
+   mpc->playlist_format = g_strdup(PLAYLIST_FORMAT);
    mpc->show_frame = TRUE;
    mpc->playlist = NULL;
    mpc->mpd_outputs = g_new(t_mpd_output*,1);
@@ -857,6 +957,11 @@ mpc_construct (XfcePanelPlugin * plugin)
 
    /* create a connection*/
    mpc->mo = mpd_new(mpc->mpd_host,mpc->mpd_port,mpc->mpd_password);
+   if (mpc_plugin_reconnect (mpc)) {
+      if (mpd_status_update (mpc->mo) == MPD_OK &&
+          mpd_player_get_state(mpc->mo) == MPD_PLAYER_PLAY)
+          mpc_launch_streaming(mpc);
+   }
 
    gtk_container_add (GTK_CONTAINER (plugin), mpc->frame);
    gtk_frame_set_shadow_type (GTK_FRAME (mpc->frame), ((mpc->show_frame) ? GTK_SHADOW_IN : GTK_SHADOW_NONE));
