@@ -38,12 +38,15 @@ typedef struct {
 
 typedef struct {
    XfcePanelPlugin *plugin;
-   GtkWidget *frame,*box,*prev,*stop,*toggle,*next,*random,*repeat,*appl,*about;
+   GtkWidget *frame,*box,*prev,*stop,*toggle,*next,*random,*repeat,*stream,*appl,*about;
    GtkWidget *playlist;
    gboolean show_frame;
    /* mpd handle */
    MpdObj *mo;
    gchar* client_appl;
+   gchar* streaming_appl;
+   gboolean is_streaming;
+   GPid streaming_child_pid;
    gchar* mpd_host;
    gint mpd_port;
    gchar * mpd_password;
@@ -61,6 +64,7 @@ typedef struct {
    GtkWidget *textbox_port;
    GtkWidget *textbox_password;
    GtkWidget *textbox_client_appl;
+   GtkWidget *textbox_streaming_appl;
    GtkWidget *textbox_tooltip_format;
    GtkWidget *textbox_playlist_format;
    GtkWidget *checkbox_frame;
